@@ -1,8 +1,12 @@
 context("testing entity functions")
+source("utils.R")
 
 test_that("getting named entities works", {
     skip_on_cran()
-    skip_on_appveyor()
+    # skip_on_appveyor()
+    skip_on_os("solaris")
+    skip_if_no_python_or_no_spacy()
+    
     expect_message(spacy_initialize(), "successfully")
     
     txt1 <- c(doc1 = "The United States elected President Donald Trump, from New York.", 
@@ -44,7 +48,9 @@ test_that("getting named entities works", {
 
 test_that("entity consolidation works", {
     skip_on_cran()
-    skip_on_appveyor()
+    # skip_on_appveyor()
+    skip_on_os("solaris")
+    skip_if_no_python_or_no_spacy()
     expect_message(spacy_initialize(), "successfully")
     
     txt1 <- c(doc1 = "The United States elected President Donald Trump, from New York.", 
