@@ -1,9 +1,12 @@
 context("test quanteda functions")
+source("utils.R")
 
 test_that("quanteda functions work", {
     skip_on_cran()
-    skip_on_appveyor()
+    # skip_on_appveyor()
+    skip_on_os("solaris")
     skip_if_not_installed("quanteda")
+    skip_if_no_python_or_no_spacy()
     
     spacy_initialize()
     
@@ -37,4 +40,4 @@ test_that("quanteda functions work", {
     )
 
     spacy_finalize()
-})
\ No newline at end of file
+})
